Coverage for pygeodesy/deprecated/__init__.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''DEPRECATED classes, constants, functions, interns, methods, etc. and all

5 lazily imported.

6

7 Kept for backward compatibility, including DEPRECATED modules C{pygeodesy.bases},

8 C{pygeodesy.datum} and C{pygeodesy.nvector}. Use either C{from pygeodesy import

9 bases} or C{from pygeodesy.deprecated import bases}. Likewise for C{datum} and

10 C{nvector}.

11'''

12

13 from pygeodesy.deprecated.bases import * # noqa: F403 not pygeodesy.__init__

14 from pygeodesy.deprecated.datum import * # noqa: F403 not pygeodesy.__init__

15 from pygeodesy.deprecated.nvector import * # noqa: F403 not pygeodesy.__init__

16

17 from pygeodesy.deprecated.classes import * # noqa: F403

18 from pygeodesy.deprecated.consterns import * # noqa: F403

19 from pygeodesy.deprecated.functions import * # noqa: F403

20

21 from pygeodesy.lazily import _ALL_ATTRS, _ALL_DEPRECATED, _lazy_import_as, _unLazy0 # _lazy_import_star

22

23 __all__ = (_ALL_DEPRECATED.deprecated_bases +

24 _ALL_DEPRECATED.deprecated_datum +

25 _ALL_DEPRECATED.deprecated_nvector +

26

27 _ALL_DEPRECATED.deprecated_classes +

28 _ALL_DEPRECATED.deprecated_consterns +

29 _ALL_DEPRECATED.deprecated_functions)

30 __version__ = '26.02.08'

31

32 if _unLazy0:

33 from pygeodesy.deprecated import bases, datum, nvector, rhumbBase, \

34 rhumbaux, rhumbsolve, rhumbx # noqa: F401 PYCHOK expected

35 __all__ += _ALL_ATTRS(_ALL_DEPRECATED.deprecated) # DEPRECATED modules

36

37 else: # lazily import modules and exported attrs

38 __getattr__ = _lazy_import_as(__name__)

39# __star__ = _lazy_import_star(__name__)

40

41# **) MIT License

42#

43# Copyright (C) 2018-2026 -- mrJean1 at Gmail -- All Rights Reserved.

44#

45# Permission is hereby granted, free of charge, to any person obtaining a

46# copy of this software and associated documentation files (the "Software"),

47# to deal in the Software without restriction, including without limitation

48# the rights to use, copy, modify, merge, publish, distribute, sublicense,

49# and/or sell copies of the Software, and to permit persons to whom the

50# Software is furnished to do so, subject to the following conditions:

51#

52# The above copyright notice and this permission notice shall be included

53# in all copies or substantial portions of the Software.

54#

55# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

56# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

57# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

58# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

59# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

60# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

61# OTHER DEALINGS IN THE SOFTWARE.